Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(828)

Unified Diff: media/audio/audio_parameters.h

Issue 4661001: Simplified AudioOutputStream interface. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: addressed all comments Created 10 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/audio/audio_parameters.h
diff --git a/media/audio/audio_parameters.h b/media/audio/audio_parameters.h
index b7b8ae507e3f75e2a91e90eed3d83e4ffad81c07..355c5e808d93237873f637099e73f810d6c46b38 100644
--- a/media/audio/audio_parameters.h
+++ b/media/audio/audio_parameters.h
@@ -24,15 +24,17 @@ struct AudioParameters {
AudioParameters();
- AudioParameters(Format format, int channels,
- int sample_rate, int bits_per_sample);
+ AudioParameters(Format format, int channels, int sample_rate,
+ int bits_per_sample, int samples_per_packet);
bool IsValid() const;
+ int GetPacketSize() const;
scherkus (not reviewing) 2010/11/11 01:25:32 could you add some documentation to these two meth
Sergey Ulanov 2010/11/11 03:06:24 Done.
- Format format; // Format of the stream.
- int channels; // Number of channels.
- int sample_rate; // Sampling frequency/rate.
- int bits_per_sample; // Number of bits per sample.
+ Format format; // Format of the stream.
+ int channels; // Number of channels.
+ int sample_rate; // Sampling frequency/rate.
+ int bits_per_sample; // Number of bits per sample.
+ int samples_per_packet; // Size of a packet in frames.
};
#endif // MEDIA_AUDIO_AUDIO_PARAMETERS_H_

Powered by Google App Engine
This is Rietveld 408576698